/*
 Model Data Constants and Structures
 (c) 2005 Vadim Kushnir
*/
#ifndef _MODEL_H
#define _MODEL_H

// Versions
#define	DATA_VER_MAJOR	0
#define	DATA_VER_MINOR	4

// Model types
#define TYPE_HELI		0
#define TYPE_PLANE		1
#define TYPE_GLIDER		2

// Fly modes
#define	M_NORMAL		0
#define	M_IDLEUP1		1
#define	M_IDLEUP2		2
#define	M_THOLD			3
#define	MAX_MODES		4

//Channels
#define CHAN_AIL		0
#define CHAN_ELE		1
#define CHAN_THR		2
#define CHAN_RUD		3
#define CHAN_GYRO		4
#define CHAN_PITCH		5
#define CHAN_GOV		6
#define CHAN_AUX1		7
#define CHAN_AUX2		8
#define MAX_CHANS		9
#define CHAN_MIN    	9
#define CHAN_MID		10
#define CHAN_MAX		11
#define CHAN_SW_L		12
#define CHAN_SW_R		13
#define CHAN_NONE		14

// TX Modulation types
#define MODUL_PPM       0
#define MODUL_IPPM      1
#define MODUL_PCM       2
#define MAX_MODULS		3

#define CURVE_NODES		7

//Channel
typedef struct {
	char		reverse;
	char		maxEPA;						// EPA val in 2% unit
	char		minEPA;						// EPA val in 2% unit
	schar		cntPos;						// central position
	schar		exponent;					// T-Cut for throttle channel
	char		reserve;
	char		nodes[CURVE_NODES];
} CHAN_SETTINGS;

//Model
typedef struct {
	char			version[2];			// Major and Minor version of data structure
	char			name[8];			// name of model (max 8 chars)
	char			type;				// heli, plane, etc.
	char			subtype;			// swasplate type for heli, etc.
	schar			modulation;			// PPM, IPPM, PCM
    schar           modulParams[4];     // for PPM, IPPM: [0] - pause in 10 us units, [1..3] - reserved
	char			chanMap[MAX_CHANS];	// channels assignement		
	schar			trimmer[MAX_MODES][4];
	CHAN_SETTINGS	chans[MAX_MODES][MAX_CHANS];
	char			revomix[MAX_MODES][CURVE_NODES];    // not sure if required or not
    uchar           crc[2];             // H, L
} MODEL_SETTINGS;

void setModelDefaults(MODEL_SETTINGS *m);
short mixChannel(char chan);

#ifdef _WIN32
 char downloadModel();
 char uploadModel();
#endif // _WIN32

#endif // _MODEL_H
